.. currentmodule:: sardana.pool.pool

:mod:`~sardana.pool.pool`
=========================

.. automodule:: sardana.pool.pool

.. rubric:: Functions

.. hlist::
    :columns: 3

    * :func:`get_thread_pool`

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`Pool`

Pool
-----

.. inheritance-diagram:: Pool
    :parts: 1
    
.. autoclass:: Pool
    :show-inheritance:
    :members:
    :undoc-members:
